@@ -35,7 +35,7 @@ DISTRO_PRETTY_NAME = {
     'centos': 'CentOS Stream 9',
     'debian': 'Debian GNU/Linux 12 (bookworm)',
     'rocky': 'Rocky Linux 9.* (Blue Onyx)',
-    'ubuntu': 'Ubuntu 22.04',
+    'ubuntu': 'Ubuntu 2{2,4}.04',
 }
 OPENSTACK_RELEASE = '2024.1'
 
@@ -386,6 +386,9 @@ def parse(conf, args, usage=None, prog=None,
     openstack_branch_slashed = openstack_branch.replace('-', '/')
     conf.set_default('openstack_branch', openstack_branch)
     conf.set_default('openstack_branch_slashed', openstack_branch_slashed)
+    # NOTE(bbezak) Derive debian_arch from base_arch if not set explicitly
+    derived_arch = 'arm64' if conf.base_arch == 'aarch64' else 'amd64'
+    conf.set_default('debian_arch', derived_arch)
 
     if not conf.base_image:
         conf.base_image = DEFAULT_BASE_TAGS[conf.base]['name']
