@@ -122,7 +122,10 @@ class KollaWorker(object):
             self.distro_package_manager = 'apt'
             self.base_package_type = 'deb'
         elif self.base in ['ubuntu']:
-            self.conf.distro_python_version = "3.10"
+            if self.base_tag.startswith(('24.04', 'noble')):
+                self.conf.distro_python_version = "3.12"
+            else:
+                self.conf.distro_python_version = "3.10"
             self.distro_package_manager = 'apt'
             self.base_package_type = 'deb'
         else:
@@ -564,6 +567,26 @@ class KollaWorker(object):
                     'name': name,
                 })
 
+        if self.conf.format == 'json':
+
+            def json_summary(f, **kwargs):
+                json.dump(results, f, **kwargs)
+
+            if self.conf.summary_json_file:
+                try:
+                    with open(self.conf.summary_json_file, "w") as f:
+                        json_summary(f, indent=4)
+                except OSError as e:
+                    LOG.error(f'Failed to write JSON build summary to '
+                              '{self.conf.summary_json_file}')
+                    LOG.error(f'Exception caught: {e}')
+                    sys.exit(1)
+
+            else:
+                # NOTE(mgoddard): Keep single line output for
+                # backwards-compatibility.
+                json_summary(sys.stdout)
+
         return results
 
     def get_image_statuses(self):
@@ -616,6 +639,7 @@ class KollaWorker(object):
                 if installation['type'] == 'git':
                     installation['reference'] = self.conf[section]['reference']
                 installation['enabled'] = self.conf[section]['enabled']
+                installation['sha256'] = self.conf[section]['sha256']
             return installation
 
         all_sections = (set(self.conf._groups.keys()) |
